# batgrl
<sup>**b**ad**a**ss **t**erminal **gr**aphics **l**ibrary</sup>

Create games:

![Tetris](https://raw.githubusercontent.com/salt-die/batgrl/main/preview_images/tetris.png)

Simulations:

![Simulation](https://raw.githubusercontent.com/salt-die/batgrl/main/preview_images/simulation.png)

Or entire feature-filled applications:

![Application](https://raw.githubusercontent.com/salt-die/batgrl/main/preview_images/application.png)

[See it in action](https://youtu.be/FzQP86ljsgc)

[Read the docs](https://salt-die.github.io/batgrl/index.html)
